@@ -31,9 +31,10 @@ func init() {
 }
 
 type Backup struct {
-	cn   *pbm.PBM
-	node *pbm.Node
-	typ  pbm.BackupType
+	cn       *pbm.PBM
+	node     *pbm.Node
+	typ      pbm.BackupType
+	incrBase bool
 }
 
 func New(cn *pbm.PBM, node *pbm.Node) *Backup {
@@ -52,6 +53,15 @@ func NewPhysical(cn *pbm.PBM, node *pbm.Node) *Backup {
 	}
 }
 
+func NewIncremental(cn *pbm.PBM, node *pbm.Node, base bool) *Backup {
+	return &Backup{
+		cn:       cn,
+		node:     node,
+		typ:      pbm.IncrementalBackup,
+		incrBase: base,
+	}
+}
+
 func (b *Backup) Init(bcp *pbm.BackupCmd, opid pbm.OPID, balancer pbm.BalancerMode) error {
 	ts, err := b.cn.ClusterTime()
 	if err != nil {
@@ -101,6 +111,7 @@ func (b *Backup) Run(ctx context.Context, bcp *pbm.BackupCmd, opid pbm.OPID, l *
 
 	rsMeta := pbm.BackupReplset{
 		Name:         inf.SetName,
+		Node:         inf.Me,
 		StartTS:      time.Now().UTC().Unix(),
 		Status:       pbm.StatusRunning,
 		Conditions:   []pbm.Condition{},
@@ -216,7 +227,7 @@ func (b *Backup) Run(ctx context.Context, bcp *pbm.BackupCmd, opid pbm.OPID, l *
 	switch b.typ {
 	case pbm.LogicalBackup:
 		err = b.doLogical(ctx, bcp, opid, &rsMeta, inf, stg, l)
-	case pbm.PhysicalBackup:
+	case pbm.PhysicalBackup, pbm.IncrementalBackup:
 		err = b.doPhysical(ctx, bcp, opid, &rsMeta, inf, stg, l)
 	default:
 		return errors.New("undefined backup type")
