@@ -30,6 +30,14 @@ import (
 	"github.com/percona/percona-backup-mongodb/pbm/snapshot"
 )
 
+type Record = db.Oplog
+
+// OpFilter can be used to filter out oplog records by content.
+// Useful for apply only subset of operations depending on conditions
+type OpFilter func(*Record) bool
+
+func DefaultOpFilter(*Record) bool { return true }
+
 var excludeFromOplog = []string{
 	"config.rangeDeletions",
 	pbm.DB + "." + pbm.TmpUsersCollection,
@@ -56,6 +64,20 @@ var knownCommands = map[string]struct{}{
 	"commitIndexBuild": {},
 }
 
+var selectedNSSupportedCommands = []string{
+	"create",
+	"drop",
+	"createIndexes",
+	"deleteIndex",
+	"deleteIndexes",
+	"dropIndex",
+	"dropIndexes",
+	"collMod",
+	"startIndexBuild",
+	"abortIndexBuild",
+	"commitIndexBuild",
+}
+
 var dontPreserveUUID = []string{
 	"admin.system.users",
 	"admin.system.roles",
@@ -74,7 +96,7 @@ type OplogRestore struct {
 	endTS             primitive.Timestamp
 	indexCatalog      *idx.IndexCatalog
 	excludeNS         *ns.Matcher
-	includeNS         *ns.Matcher
+	includeNS         map[string]map[string]bool
 	noUUIDns          *ns.Matcher
 
 	txn        chan pbm.RestoreTxn
@@ -89,6 +111,8 @@ type OplogRestore struct {
 	cnamespase   string
 
 	unsafe bool
+
+	filter OpFilter
 }
 
 // NewOplogRestore creates an object for an oplog applying
@@ -121,9 +145,19 @@ func NewOplogRestore(dst *pbm.Node, sv *pbm.MongoVersion, unsafe, preserveUUID b
 		txn:               ctxn,
 		txnSyncErr:        txnErr,
 		unsafe:            unsafe,
+		filter:            DefaultOpFilter,
 	}, nil
 }
 
+// SetOpFilter allows to restrict skip ops by specific conditions
+func (o *OplogRestore) SetOpFilter(f OpFilter) {
+	if f == nil {
+		f = DefaultOpFilter
+	}
+
+	o.filter = f
+}
+
 // SetTimeframe sets boundaries for the replayed operations. All operations
 // that happened before `start` and after `end` are going to be discarded.
 // Zero `end` (primitive.Timestamp{T:0}) means all chunks will be replayed
@@ -175,18 +209,57 @@ func (o *OplogRestore) Apply(src io.ReadCloser) (lts primitive.Timestamp, err er
 	return lts, bsonSource.Err()
 }
 
-func (o *OplogRestore) SetIncludeNSS(nss []string) error {
+func (o *OplogRestore) SetIncludeNS(nss []string) {
 	if len(nss) == 0 {
-		return nil
+		o.includeNS = nil
+		return
 	}
 
-	m, err := ns.NewMatcher(nss)
-	if err != nil {
-		return err
+	dbs := make(map[string]map[string]bool)
+	for _, ns := range nss {
+		d, c, _ := strings.Cut(ns, ".")
+		if d == "*" {
+			d = ""
+		}
+		if c == "*" {
+			c = ""
+		}
+
+		colls := dbs[d]
+		if colls == nil {
+			colls = make(map[string]bool)
+		}
+		colls[c] = true
+		dbs[d] = colls
 	}
 
-	o.includeNS = m
-	return nil
+	o.includeNS = dbs
+}
+
+func (o *OplogRestore) isOpSelected(oe *Record) bool {
+	if o.includeNS == nil || o.includeNS[""] != nil {
+		return true
+	}
+
+	d, c, _ := strings.Cut(oe.Namespace, ".")
+	colls := o.includeNS[d]
+	if colls[""] || colls[c] {
+		return true
+	}
+
+	if oe.Operation != "c" || c != "$cmd" {
+		return false
+	}
+
+	m := oe.Object.Map()
+	for _, cmd := range selectedNSSupportedCommands {
+		if ns, ok := m[cmd]; ok {
+			s, _ := ns.(string)
+			return colls[s]
+		}
+	}
+
+	return false
 }
 
 func (o *OplogRestore) LastOpTS() uint32 {
@@ -208,7 +281,11 @@ func (o *OplogRestore) handleOp(oe db.Oplog) error {
 		return nil
 	}
 
-	if o.includeNS != nil && !o.includeNS.Has(oe.Namespace) {
+	if !o.isOpSelected(&oe) {
+		return nil
+	}
+
+	if !o.filter(&oe) {
 		return nil
 	}
 
